<?PHP

/*
  --------------------------------------------------------------------------
  Sphere Visible Fraction of Surface Calculator

  This program computes the visible or illuminated fraction of a spherical
  surface as viewed from any given from its center or above its surface.

  Author:
  Jay Tanner - 2019

  Current Web Site
  www.NeoProgrammics.com

  Development Language:
  PHP v7.1.8

  License:
  This program source code and any related data and graphics are released
  under the provisions of the Creative Commons Attribution-ShareAlike 4.0
  International.

  https://creativecommons.org/licenses/by-sa/4.0/legalcode
  --------------------------------------------------------------------------

*/

   function Strip_Whitespace ($TextString)
{
   return preg_replace("/\s+/", " ", trim($TextString));
}





/*
   ---------------------------------------
   This function simply swaps the contents
   of the two given variable arguments.
*/

   function Swap (&$var1, &$var2)
 {
   $w=$var1;  $var1=$var2;  $var2=$w;
 }


   $cYear = date("Y");

   $_ACTION_FILE_NAME_ = $_SERVER['SCRIPT_NAME'];


// Initialize error detection flag state
   $ErrorFlag = FALSE;

// Read radius and distance argument values
// from input interface.
   $R = trim(@$_POST['R']);
   $D = trim(@$_POST['D']);

// Set initial radius and distance default values in miles.
   if ($R == "" && $D == "") {$R = 1079.35;   $D = 238856;}

// Read selected radio button value
   $RadioButtonIndex = trim(@$_POST['DistOption']);

// Set default selected radio button to
// distance measured from center.
   if ($RadioButtonIndex == ""){$RadioButtonIndex = 0;}

// Set number of radio buttons.
// In this case 2 buttons.
   $n = 2;

// Create radio button states array
   for ($i=0;   $i < $n;   $i++)
       {
        if ($i == $RadioButtonIndex)
           {$RadioButton[$i] = "CHECKED";} else {$RadioButton[$i] = "";}
       }

// Error if either argument is non-numeric
   if (!is_numeric($R) || !is_numeric($D))
      {
       $ErrorFlag = TRUE;
       $out = "Error: Both arguments should be positive numeric values.\n";
      }

// Convert both arguments to absolute values.
   if ($R < 0) {$R = abs($R);}
   if ($D < 0) {$D = abs($D);}

// Handle computation for distance
// measured from center of sphere.
   if ($RadioButtonIndex == 0 && $ErrorFlag == FALSE)
{
   if ($R >= $D)
      {$ErrorFlag = TRUE;
       $out = "<Error :  Distance from center must be greater than radius.\n";
      }
   else
      {
   $Rs = ($R == 1)? '':'s';
   $Ds = ($D == 1)? '':'s';

   $out = "For a sphere of radius $R unit$Rs, where the distance to the eye\nor point-light source is $D unit$Ds from the center:\n\n";

   $VisFrac = sprintf("%1.6f", (100 * ($D - $R) / (2 * $D)));
   $out .= "Visible or illuminated fraction of surface = $VisFrac percent";

   $InvisFrac = sprintf("%1.6f", 100 - $VisFrac);
   $out = "$out\n\nInvisible or shaded fraction = $InvisFrac percent";

       $diff = sprintf("%1.6f", $InvisFrac - $VisFrac);
       $out = "$out\n\nDifference = $diff percent";
}
}


// Handle computation for distance
// measured from surface of sphere.
   if ($RadioButtonIndex == 1 && $ErrorFlag == FALSE)
{
   if ($D <= 0 or $R < 0)
      {
       $ErrorFlag = TRUE;
       $out = "<B CLASS=\"TxRed\">Error : &nbsp; Radius and distance should both be greater than zero.</B>\n";
      }
   else
      {
       $Rs = ($R == 1)? '':'s';
       $Ds = ($D == 1)? '':'s';
       $out = "For a sphere of radius <code>$R</code> unit$Rs, where the distance to the eye<br>or point-light source is <code>$D</code> unit$Ds from the surface:<br><br>";
       $VisFrac = sprintf("%1.6f", 100*$D / (2*($R+$D)));
       $out .= "Visible or illuminated fraction of surface = <code>" . $VisFrac . "</code> percent";

       $InvisFrac = sprintf("%1.6f", 100 - $VisFrac);
       $out = "$out<br>Invisible or shaded fraction = <code>$InvisFrac</code> percent";

       $diff = sprintf("%1.6f", $InvisFrac - $VisFrac);
       $out = "$out<br>Difference = <code>$diff</code> percent";
      }
}

// Generate start of HTML page

print <<< _HTML

<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">

<HTML>

<HEAD>

<META HTTP-EQUIV="CONTENT-TYPE" CONTENT="TEXT/HTML; CHARSET=UTF-8">

<link href='../css/custom_styles_theme_01.css' type='text/css' rel='stylesheet'>

<style type='text/css' rel='stylesheet'>
BODY {background-color:black; color:white; font-family:Verdana; font-size:14px;}

TEXTAREA {font-family:monospace; text-align:left; font-size:19px; font-weight:bold; padding:4px; border:1px solid black;}

TABLE {background-color:black; font-family:Verdana,sans-serif; font-size:14px;}

TD {background-color:white; color:black; font-size:100%; text-align:center; line-height:150%;}

HR {background-color:black; height:2px; border:0px;}

IMG {box-shadow:6px 6px 6px #999999; border:1px solid #BBBBBB; border-radius:8px;}

INPUT[type="submit"] {box-shadow:3px 3px 4px #999999;}

INPUT[type="text"] {box-shadow:3px 3px 4px #999999; background-color:white; font-family:monospace; font-size:18px; font-weight:bold; text-align:center; border:2px solid black;}

INPUT[type="text"]::-ms-clear {width:0; height:0;}

INPUT[type="text"]:focus {box-shadow:3px 3px 4px #999999;background-color:white; font-family:monospace; font-size:18px; border:2px solid red; text-align:center; font-weight:bold;}

A:link,  A:visited {background-color:transparent; color:blue; font-family:Verdana; font-size:12px; font-weight:bold; text-decoration:none; line-height:150%; padding:2px;}
A:hover, A:active  {background-color:transparent; color:red;  font-family:Verdana; font-size:12px; font-weight:bold; text-decoration:none; line-height:150%; padding:2px;}

::-ms-selection  {background-color:yellow; color:black;}  /* Only applies to IE9+ and Safari     */
::-moz-selection {background-color:yellow; color:black;}  /* Only applies to Mozilla and FireFox */
</style>

<META NAME="robots" CONTENT="index,follow">

<TITLE>Visible Fraction Of Total Surface Area Of A Sphere</TITLE>

<script type="text/javascript" src="../MathJax/MathJax.js?config=TeX-AMS-MML_HTMLorMML"></script>
<script type="text/x-mathjax-config">MathJax.Hub.Config({tex2jax: {inlineMath: [['$','$'], ['\\(','\\)']], displayMath: [['\\[','\\]'], ['$$','$$']]}});</script>

</HEAD>

<BODY BGCOLOR="white">

<TABLE WIDTH="600" CELLPADDING="4" CELLSPACING="1">
<tr><td style='color:white; background-color:#0000DD; padding:4px; border:2px solid white; border-radius:8px 8px 0px 0px;'><B>Visible or Illuminated Fraction of Total Surface Area of a Sphere</B></td><tr>
<TR><TD>
<DIV>
This program computes the ideal visible fraction or illuminated fraction of the total surface area of a sphere at any distance from the eye or point-light source as reckoned from the center or surface of the sphere.
<BR><BR>
The radius and distance can be in any convenient linear units. &nbsp; The default values are the mean lunar radius and the mean geocentric lunar distance in statute miles.
<br><br>
In the lunar equations below:<br>
<b>R</b> = Mean Lunar Radius = 1737.05 km = 1079.35 mi

<BR><BR>
<FORM NAME="form1" ACTION="$_ACTION_FILE_NAME_" METHOD="post">

<TABLE width='600' CELLPADDING="6" CELLSPACING="1">

<TR><TD style='color:black; background-color:white;' ALIGN="center"><B>Radius</B></TD>
<TD style='color:black; background-color:LightCyan; text-align:center;'><INPUT CLASS="TxIO" NAME="R" TYPE="text" SIZE="24" VALUE="$R" MAXLENGTH="24"> units</TD></TR>

<TR><TD style='color:white; background-color:black;' ALIGN="center"><B>Distance</B></TD>
<TD style='color:black; background-color:LightCyan; text-align:center;'><INPUT NAME="D" TYPE="text" SIZE="24" VALUE="$D" MAXLENGTH="24"> units</TD></TR>

<TR><TD style='color:black; background-color:white; font-size:85%;' ALIGN="center" COLSPAN="2"><B>Distance To Point Reckoned From: &nbsp;&nbsp;&nbsp; </B>Center &nbsp;<INPUT NAME="DistOption" TYPE="radio" VALUE="0" $RadioButton[0]>
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Surface &nbsp;<INPUT NAME="DistOption" TYPE="radio" VALUE="1" $RadioButton[1]></TD></TR>

<TR><TD COLSPAN="2" style='background-color:#DDDDDD;' ALIGN="center"><INPUT NAME="Compute_Button" TYPE="submit" VALUE="Compute"></TD></TR>

</TABLE>

</FORM>

<div align='center' style='font-size:14px; font-weight:bold; background-color:LightYellow;'>
<pre style='border-radius:8px;'>$out</pre>
</div>

<hr>


<br><br>

<table width='100%' bgcolor="white" cellpadding='6'>
<tr><td><IMG SRC="images/sphere_view_0.png" ALT="">
<br>
</td></tr>
<tr><td><div style='text-align:center;'><b>A Sphere and a Point</b></div>
<br>
<div>
Mathematically, this is a problem involving a simple point and a sphere in 3D space. &nbsp; The tiny white point in the diagram above could represent different things, depending on the context, for astronomical purposes, the sphere representing a spherical planet or moon.
<br><br>
If the point represented a point-light source, then it would simply illuminate the sphere as shown.&nbsp; The farther away the point, the larger the area reached by the light, but the fainter the recieved light would be, up to a maximum limit of reaching 50 percent of the total surface at infinity.
<br><br>
If the point represented the eye or camera lens, then the illuminated area would indicate the ideal fraction of the total spherical surface area visible from that point. &nbsp; The farther away the eye, the greater the visible surface becomes, but the smaller the visible image would be, up to a maximum limit of seeing 50 percent of the total surface at infinity.
<br><br>
The distance between the point and the sphere can be reckoned either from the center or from the surface of the sphere, whichever is more convenient or practical for a particular application.
<br><br>
The distance between a point and the surface of a sphere equates to the radar distance or the shortest distance between the surface of the sphere and the point.&nbsp; In space, we can send a radar signal to determine our distance from the surface of the moon.&nbsp; This to-the-surface distance is probably more convenient for some applications than using the distance to the center of the moon, such as landing computations.
<br><br>
</div>
</td></tr>
<table>

<br><br>

<!--                  -->

<table width='100%' bgcolor="white" cellpadding='6'>
<tr><td><IMG SRC="images/sphere_vis_frac_from_center.png" ALT=""></td></tr>
<tr><td>
<DIV style='text-align:center;'><B>Where the Distance to the Point is Reckoned<br>From the Center of the Sphere:</B></DIV>
<BR>
<DIV>
Given the radius (<CODE>R</CODE>) of the sphere and the distance (<CODE>D</CODE>) of the point from the center, the general equation for the potential fraction (<CODE>f</CODE>) of the total surface area of the sphere as viewed or illuminated from that point is:
<br><br>

<div style='text-align:center;'><img src='images/eq1.png'></div>

<div>As the distance (<code>D</code>) from the center of the sphere increases towards infinity, we can see slightly more and more of the surface but then we have to magnify the image more and more to make out details, to the extent of the limits of our imaging technology.&nbsp;

<br><br>
As the distance from the sphere approaches infinity, the potentially visible or illuminated fraction (<b>f</b>) approaches a maximum limit of <code>0.5</code> (<code>1/2</code>) of the total surface area.&nbsp;

<br><br>
For the moon, at (<b>D</b>) kilometers or statute miles from the center:
<br><br>

<div style='text-align:center;'><img src='images/eq2.png'></div>

</div>
</td></tr>
</table>
<br><br>


<table width='100%' bgcolor="white" cellpadding='6'>
<tr><td><IMG SRC="images/sphere_vis_frac_from_surface.png" ALT=""></td></tr>
<tr><td>
<DIV style='font-size:90%; text-align:center;'><B>Where the Distance to the Point is Reckoned<br>From the Surface of the Sphere:</B></DIV>
<BR>
<DIV style='font-size:90%;'>
Given the radius (<b>R</b>) of the sphere and the distance (<b>d</b>) of the point from its surface, the general equation for the ideal fraction (<b>f</b>) of the total surface area of the sphere as viewed or illuminated from that point is:</div>

<div style='text-align:center;'><img src='images/eq3.png'></div>

<div style='font-size:90%;'>
<br><br>
As the distance from the surface of the sphere approaches infinity, the potentially visible or illuminated fraction (<b>f</b>) approaches a maximum limit of <code>0.5</code> (<code>1/2</code>) of the total surface area.
</div>

<DIV style='font-size:90%;'>For the moon, at (<b>d</b>) kilometers or statute miles from the surface:</div>

<div style='text-align:center;'><img src='images/eq4.png'></div>

</DIV>

<br>
In the lunar equations above:<br>
<b>R</b> = Mean Lunar Radius = 1737.05 km = 1079.35 mi

<br><br>
<DIV style='font-size:70%; color:gray; text-align:center;'><B>$cYear - Jay Tanner</B></DIV>

</TD></TR>


</TABLE>

_HTML;


// Generate end of HTML page

print <<< _HTML

</DIV>

</BODY>
</HTML>

_HTML;

?>


